Learn R Programming

metaCluster (version 0.1.1)

oligo.freq: Oligonucleotide Frequency

Description

This function will calculate oligonucleotide frequency of each sequence or contig from a FASTA file.

Usage

oligo.freq(fasta_file, f)

Value

Frequency value of each oligonucleotide of length specified by the user

Arguments

fasta_file

Name of the fasta or multifasta file

f

Length of the oligonucleotide

Author

Dipro Sinha <diprosinha@gmail.com>,Sayanti Guha Majumdar, Anu Sharma, Dwijesh Chandra Mishra

Examples

Run this code
library(metaCluster)
freq <- oligo.freq(fasta_file = system.file("extdata/sample1.fasta", package = "metaCluster"),4)

Run the code above in your browser using DataLab