powered by
This function will calculate oligonucleotide frequency of each sequence or contig from a FASTA file.
oligo.freq(fasta_file, f)
Frequency value of each oligonucleotide of length specified by the user
Name of the fasta or multifasta file
Length of the oligonucleotide
Dipro Sinha <diprosinha@gmail.com>,Sayanti Guha Majumdar, Anu Sharma, Dwijesh Chandra Mishra
library(metaCluster) freq <- oligo.freq(fasta_file = system.file("extdata/sample1.fasta", package = "metaCluster"),4)
Run the code above in your browser using DataLab